| cohort_institution | R Documentation |
A dataset containing the institutions participating in curation of each cancer cohort
cohort_institution
A lookup table for institutions participating in curation by cancer cohort
GENIE BPC Project cancer. One of "NSCLC" (non-small cell lung cancer), "CRC" (colorectal cancer), "BrCa" (breast cancer), "PANC" (pancreatic cancer), "Prostate" (prostate cancer), "BLADDER" (bladder cancer), and "RENAL" (renal cancer).
GENIE BPC participating institution.
...
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.